# vtds-application-openchami

This vTDS Application Layer implementation configures, installs and deploys the OpenCHAMI
system management application on a vTDS Cluster.

NOTE: at present this Application Layer does nothing, and is a place holder for this work.
